@@ -6,7 +6,7 @@ use AnyEvent;
 use Bif::Client;
 use Coro;
 
-our $VERSION = '0.1.0_24';
+our $VERSION = '0.1.0_25';
 
 my $stderr;
 my $stderr_watcher;
@@ -103,7 +103,7 @@ sub run {
 
                     $client->on_update(
                         sub {
-                            $ctx->lprint("$hub->{name}         : $_[0]");
+                            $ctx->lprint("$hub->{name}: $_[0]");
                         }
                     );
 
@@ -118,19 +118,15 @@ sub run {
 
                     }
 
-                    $status = $client->transfer_hub_updates;
-                    if ( $status ne 'TransferHubUpdates' ) {
-                        $db->rollback;
-                        $error = "unexpected status received: $status";
-                        return cleanup_errors( $hub->{name} );
-                    }
-                    print "\n";
+                    if ( $status eq 'RepoSync' ) {
+                        $status = $client->transfer_hub_updates;
 
-                    $client->on_update(
-                        sub {
-                            $ctx->lprint("$hub->{name} (topics): $_[0]");
+                        if ( $status ne 'TransferHubUpdates' ) {
+                            $db->rollback;
+                            $error = "unexpected status received: $status";
+                            return cleanup_errors( $hub->{name} );
                         }
-                    );
+                    }
 
                     $status = $client->sync_projects;
 
@@ -180,7 +176,7 @@ bif-import -  import projects from a remote hub
 
 =head1 VERSION
 
-0.1.0_24 (2014-06-13)
+0.1.0_25 (2014-06-14)
 
 =head1 SYNOPSIS
 
