@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use App::bif::Context;
 
-our $VERSION = '0.1.0_24';
+our $VERSION = '0.1.0_25';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
@@ -107,6 +107,14 @@ sub _push_issue {
                 },
             );
 
+            my ($dhub) = $db->xarray(
+                select     => 'h.name',
+                from       => 'projects p',
+                inner_join => 'hubs h',
+                on         => 'h.id = p.hub_id',
+                where      => { 'p.id' => $pinfo->{id} },
+            );
+
             $db->xdo(
                 insert_into => 'updates',
                 values      => {
@@ -114,8 +122,9 @@ sub _push_issue {
                     parent_id => $info->{first_update_id},
                     email     => $ctx->{user}->{email},
                     author    => $ctx->{user}->{name},
-                    message   => "[ Pushed from project "
-                      . "$proj\@$hub ]\n\n$ctx->{message}",
+                    message   => "[ push: "
+                      . "$proj\@$hub -> $pinfo->{path}\@$dhub ]\n\n"
+                      . $ctx->{message},
                 },
             );
 
@@ -171,7 +180,7 @@ bif-push - push a topic to another project
 
 =head1 VERSION
 
-0.1.0_24 (2014-06-13)
+0.1.0_25 (2014-06-14)
 
 =head1 SYNOPSIS
 
