@@ -2,7 +2,6 @@ CREATE TABLE func_import_hub_delta(
     update_uuid VARCHAR(40) NOT NULL,
     hub_uuid VARCHAR(40) NOT NULL,
     name VARCHAR(128),
-    default_location_uuid VARCHAR(40),
     project_uuid VARCHAR(40),
     related_update_uuid VARCHAR(40)
 );
@@ -18,7 +17,6 @@ BEGIN
         NEW.update_uuid,
         NEW.hub_uuid,
         NEW.name,
-        NEW.default_location_uuid,
         NEW.project_uuid,
         NEW.related_update_uuid
     );
@@ -28,7 +26,6 @@ BEGIN
             update_id,
             hub_id,
             name,
-            default_location_id,
             project_id,
             related_update_uuid
         )
@@ -36,7 +33,6 @@ BEGIN
         u.id,
         hubs.id,
         NEW.name,
-        hr.id,
         p.id,
         NEW.related_update_uuid
     FROM
@@ -45,10 +41,6 @@ BEGIN
         updates u
     ON
         u.uuid = NEW.update_uuid
-    LEFT JOIN
-        topics hr
-    ON
-        hr.uuid = NEW.default_location_uuid
     LEFT JOIN
         topics p
     ON
