@@ -9,9 +9,6 @@ BEFORE INSERT ON
 FOR EACH ROW WHEN
     NEW.merge = 1
 BEGIN
-    select debug(
-        'TRIGGER func_merge_updates_bi_1'
-    );
 
     /*
         The following results in updates.uuid and updates.prefix being
@@ -28,16 +25,19 @@ BEGIN
     ;
 
     /*
-        The following updates the project_related_updates_merkle table
+        Now that updates.uuid has been set we can run the merge
+        operations that use updates.uuid as a sort field
     */
 
-    UPDATE
-        project_related_updates
-    SET
-        merkled = 1
-    WHERE
-        merkled = 0
-    ;
+    UPDATE hub_tomerge              SET resolve = 1;
+    UPDATE hub_repos_tomerge        SET resolve = 1;
+    UPDATE projects_tomerge         SET resolve = 1;
+    UPDATE project_status_tomerge   SET resolve = 1;
+    UPDATE task_status_tomerge      SET resolve = 1;
+    UPDATE issue_status_tomerge     SET resolve = 1;
+    UPDATE tasks_tomerge            SET resolve = 1;
+    UPDATE issues_tomerge           SET resolve = 1;
+    UPDATE project_issues_tomerge   SET resolve = 1;
 
     /*
         The following updates the hub_related_updates_merkle table
@@ -51,17 +51,17 @@ BEGIN
         merkled = 0
     ;
 
+    /*
+        The following updates the project_related_updates_merkle table
+    */
 
-    UPDATE hub_tomerge              SET resolve = 1;
-    UPDATE hub_repos_tomerge    SET resolve = 1;
-    UPDATE projects_tomerge          SET resolve = 1;
-    UPDATE project_status_tomerge   SET resolve = 1;
-    UPDATE task_status_tomerge      SET resolve = 1;
-    UPDATE issue_status_tomerge     SET resolve = 1;
-    UPDATE tasks_tomerge             SET resolve = 1;
-    UPDATE issues_tomerge            SET resolve = 1;
-    UPDATE project_issues_tomerge   SET resolve = 1;
-
+    UPDATE
+        project_related_updates
+    SET
+        merkled = 1
+    WHERE
+        merkled = 0
+    ;
 
     SELECT RAISE(IGNORE);
 
