@@ -6,13 +6,13 @@ CREATE TABLE func_update_task(
 );
 
 CREATE TRIGGER
-    bi_func_update_task_1
+    func_update_task_bi_1
 BEFORE INSERT ON
     func_update_task
 FOR EACH ROW BEGIN
 
     SELECT debug(
-        'TRIGGER bi_func_update_task_1',
+        'TRIGGER func_update_task_bi_1',
         NEW.id,
         NEW.update_id,
         NEW.status_id,
@@ -20,7 +20,7 @@ FOR EACH ROW BEGIN
     );
 
     INSERT INTO
-        task_updates(
+        task_deltas(
             update_id,
             task_id,
             status_id,
